changeset 48760:0006966fe2dc

(titdic-convert): Process the header part in multibyte mode.
author Kenichi Handa <handa@m17n.org>
date Mon, 09 Dec 2002 05:42:22 +0000
parents adc625ac6c52
children 45222b2891c5
files lisp/international/titdic-cnv.el
diffstat 1 files changed, 6 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/titdic-cnv.el	Mon Dec 09 01:56:15 2002 +0000
+++ b/lisp/international/titdic-cnv.el	Mon Dec 09 05:42:22 2002 +0000
@@ -173,7 +173,7 @@
     ("chinese-tonepy" "$A5wF4(B"
      "Pinyin base input method for Chinese charset GB2312 (`chinese-gb2312').
 
-Pinyin is the standared roman transliteration method for Chinese.
+Pinyin is the standard roman transliteration method for Chinese.
 For the details of Pinyin system, see the documentation of the input
 method `chinese-py'.
 
@@ -499,7 +499,10 @@
 	  (if (not (search-forward "\nBEGIN" nil t))
 	      (error "TIT dictionary can't be decoded correctly"))
 
-	  ;; Process the header part.
+	  ;; Process the header part in multibyte mode.
+	  (with-current-buffer standard-output
+	    (set-buffer-multibyte t))
+	  (set-buffer-multibyte t)
 	  (forward-line 1)
 	  (narrow-to-region (point-min) (point))
 	  (tit-process-header filename)
@@ -850,7 +853,7 @@
 
 Pinyin base input method for Chinese charset GB2312 (`chinese-gb2312').
 
-Pinyin is the standared roman transliteration method for Chinese.
+Pinyin is the standard roman transliteration method for Chinese.
 Pinyin uses a sequence of Latin alphabetic characters for each Chinese
 character.  The sequence is made by the combination of the initials
 \(the beginning sounds) and finals (the ending sounds).